@@ -4,6 +4,7 @@ module Network.IRC.Bot
     , module Network.IRC.Bot.Core
     , module Network.IRC.Bot.Log
     , module Network.IRC.Bot.Parsec
+    , module Network.IRC.Bot.Run
     ) where
 
 import Network.IRC.Bot.BotMonad
@@ -11,3 +12,4 @@ import Network.IRC.Bot.Commands
 import Network.IRC.Bot.Core
 import Network.IRC.Bot.Log
 import Network.IRC.Bot.Parsec
+import Network.IRC.Bot.Run
