@@ -1,6 +1,7 @@
 {-# LANGUAGE OverloadedStrings #-}
 module Network.IRC.Bot.Part.Hello where
 
+import Control.Monad            (void)
 import Control.Monad.Trans      (liftIO)
 import Data.Maybe               (fromMaybe)
 import Data.ByteString          (ByteString)
@@ -17,13 +18,13 @@ helloPart = parsecPart helloCommand
 
 helloCommand :: (BotMonad m) => ParsecT ByteString () m ()
 helloCommand =
-    do try $ botPrefix >> string "hello"
+    do void $ try $ botPrefix >> string "hello"
        logM Debug "helloPart"
        target <- maybeZero =<< replyTo
        logM Debug $ "target: " <> target
        mNick <- askSenderNickName
        let greetings = ["Hello", "Howdy", "Greetings", "Word up"]
        n <- liftIO $ randomRIO (0, length greetings - 1)
-       let msg = greetings!!n <> ", " <> (fromMaybe "stranger" mNick)
-       sendCommand (PrivMsg Nothing [target] msg)
+       let message = greetings!!n <> ", " <> (fromMaybe "stranger" mNick)
+       sendCommand (PrivMsg Nothing [target] message)
     <|> return ()
